@@ -1,6 +1,7 @@
-from ytmusicapi.ytmusic import YTMusic
+from importlib.metadata import PackageNotFoundError, version
+
 from ytmusicapi.setup import setup, setup_oauth
-from importlib.metadata import version, PackageNotFoundError
+from ytmusicapi.ytmusic import YTMusic
 
 try:
     __version__ = version("ytmusicapi")
@@ -8,7 +9,7 @@ except PackageNotFoundError:
     # package is not installed
     pass
 
-__copyright__ = 'Copyright 2023 sigma67'
-__license__ = 'MIT'
-__title__ = 'ytmusicapi'
+__copyright__ = "Copyright 2023 sigma67"
+__license__ = "MIT"
+__title__ = "ytmusicapi"
 __all__ = ["YTMusic", "setup_oauth", "setup"]
