@@ -1,5 +1,5 @@
 """protocol that defines the functions available to mixins"""
-from typing import Dict, Optional, Protocol, Union
+from typing import Dict, Optional, Protocol
 
 from requests import Response
 
@@ -10,8 +10,6 @@ from ytmusicapi.parsers.i18n import Parser
 class MixinProtocol(Protocol):
     """protocol that defines the functions available to mixins"""
 
-    auth: Optional[Union[str, Dict]]
-
     auth_type: AuthType
 
     parser: Parser
