@@ -8,13 +8,24 @@ def parse_uploaded_items(results):
         data = result[MRLIR]
         if "menu" not in data:
             continue
-        entityId = nav(data, MENU_ITEMS)[-1]["menuNavigationItemRenderer"]["navigationEndpoint"][
-            "confirmDialogEndpoint"
-        ]["content"]["confirmDialogRenderer"]["confirmButton"]["buttonRenderer"]["command"][
-            "musicDeletePrivatelyOwnedEntityCommand"
-        ]["entityId"]
-
-        videoId = nav(data, MENU_ITEMS + [0] + MENU_SERVICE)["queueAddEndpoint"]["queueTarget"]["videoId"]
+        entityId = nav(
+            data,
+            [
+                *MENU_ITEMS,
+                -1,
+                MNIR,
+                "navigationEndpoint",
+                "confirmDialogEndpoint",
+                "content",
+                "confirmDialogRenderer",
+                "confirmButton",
+                "buttonRenderer",
+                "command",
+                "musicDeletePrivatelyOwnedEntityCommand",
+                "entityId",
+            ],
+        )
+        videoId = nav(data, [*MENU_ITEMS, 0, *MENU_SERVICE])["queueAddEndpoint"]["queueTarget"]["videoId"]
 
         title = get_item_text(data, 0)
         like = nav(data, MENU_LIKE_STATUS)
